@@ -27,11 +27,10 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 
-#include "gconf-property-editor.h"
+#include "libgnome-control-center/gconf-property-editor.h"
 #include "gnome-da-capplet.h"
 #include "gnome-da-xml.h"
 #include "gnome-da-item.h"
-#include "capplet-util.h"
 
 enum
 {
@@ -287,7 +286,7 @@ screen_changed_cb (GtkWidget *widget, GdkScreen *screen, GnomeDACapplet *capplet
     if (capplet->icon_theme != NULL) {
 	g_signal_handlers_disconnect_by_func (capplet->icon_theme, theme_changed_cb, capplet);
     }
-    g_signal_connect (theme, "changed", G_CALLBACK (theme_changed_cb), capplet);
+    capplet->theme_changed_id = g_signal_connect (theme, "changed", G_CALLBACK (theme_changed_cb), capplet);
     theme_changed_cb (theme, capplet);
 
     capplet->icon_theme = theme;
