@@ -1390,6 +1390,8 @@ output_overlaps (GnomeOutputInfo *output, GnomeRRConfig *config)
     int i;
     GdkRectangle output_rect;
 
+    g_assert (output != NULL);
+
     get_output_rect (output, &output_rect);
 
     for (i = 0; config->outputs[i]; ++i)
@@ -1721,7 +1723,6 @@ paint_output (App *app, cairo_t *cr, int i)
     cairo_save (cr);
 
     foo_scroll_area_get_viewport (FOO_SCROLL_AREA (app->area), &viewport);
-
     get_geometry (output, &w, &h);
 
 #if 0
@@ -1761,7 +1762,6 @@ paint_output (App *app, cairo_t *cr, int i)
 		     - x - (w * scale + 0.5) / 2,
 		     - y - (h * scale + 0.5) / 2);
 
-
     cairo_rectangle (cr, x, y, w * scale + 0.5, h * scale + 0.5);
     cairo_clip_preserve (cr);
 
@@ -1831,8 +1831,6 @@ paint_output (App *app, cairo_t *cr, int i)
 static void
 on_area_paint (FooScrollArea  *area,
 	       cairo_t	      *cr,
-	       GdkRectangle   *extent,
-	       cairo_region_t *region,
 	       gpointer	       data)
 {
     App *app = data;
@@ -2265,6 +2263,15 @@ get_output_for_window (GnomeRRConfig *configuration, GdkWindow *window)
 				   win_rect.y + win_rect.height / 2);
 }
 
+static void
+on_toplevel_realized (GtkWidget *widget,
+                      App       *app)
+{
+  app->current_output = get_output_for_window (app->current_configuration,
+                                               gtk_widget_get_window (widget));
+  rebuild_gui (app);
+}
+
 /* We select the current output, i.e. select the one being edited, based on
  * which output is showing the configuration dialog.
  */
@@ -2275,13 +2282,14 @@ select_current_output_from_dialog_position (App *app)
 
     toplevel = gtk_widget_get_toplevel (app->panel);
 
-    if (gtk_widget_get_realized (toplevel))
+    if (gtk_widget_get_realized (toplevel)) {
 	app->current_output = get_output_for_window (app->current_configuration,
                                                      gtk_widget_get_window (toplevel));
-    else
+        rebuild_gui (app);
+    } else {
+        g_signal_connect (toplevel, "realize", G_CALLBACK (on_toplevel_realized), app);
 	app->current_output = NULL;
-
-    rebuild_gui (app);
+    }
 }
 
 /* This is a GtkWidget::map-event handler.  We wait for the display-properties
@@ -2446,7 +2454,7 @@ run_application (void)
 
     if (!app->panel)
       g_warning ("Missing display-panel object");
-    g_signal_connect_after (app->panel, "map-event",
+    g_signal_connect_after (app->panel, "show",
 			    G_CALLBACK (dialog_map_event_cb), app);
 
     app->current_monitor_event_box = _gtk_builder_get_widget (builder,
