@@ -162,8 +162,9 @@ activate_panel (GnomeControlCenter *shell,
 
           /* resize to the preferred size of the panel */
           gtk_widget_set_size_request (priv->window, FIXED_WIDTH, -1);
-          gtk_size_request_get_size (GTK_SIZE_REQUEST (priv->window), &min,
-                                     &nat);
+
+          gtk_widget_get_preferred_size (priv->window,
+                                         &min, &nat);
           gtk_window_resize (GTK_WINDOW (priv->window), FIXED_WIDTH,
                              nat.height);
           return;
@@ -483,12 +484,22 @@ search_entry_changed_cb (GtkEntry                  *entry,
   if (!g_strcmp0 (priv->filter_string, ""))
     {
       shell_show_overview_page (priv);
+      g_object_set (G_OBJECT (entry),
+                    "secondary-icon-name", "gtk-find",
+                    "secondary-icon-activatable", FALSE,
+                    "secondary-icon-sensitive", FALSE,
+                    NULL);
     }
   else
     {
       gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (priv->search_filter));
       gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
                                      SEARCH_PAGE);
+      g_object_set (G_OBJECT (entry),
+                          "secondary-icon-name", "gtk-clear",
+                          "secondary-icon-activatable", TRUE,
+                          "secondary-icon-sensitive", TRUE,
+                          NULL);
     }
 }
 
